import os.path

# An ordered list of places to search for icons, chosen to
# minimize search an maximize icons quality.
_SEARCH_POLICY = (
  "usr/share/icons/hicolor/scalable",
  "usr/share/icons/hicolor/128x128",
  "usr/share/icons/hicolor/256x256",
  "usr/share/icons/hicolor/64x64",
  "usr/share/icons/hicolor/48x48",
  "usr/share/pixmaps",
  "usr/share/icons/hicolor/32x32",
  "usr/share/icons/hicolor/22x22",
  "usr/share/icons/hicolor/16x16",
  "usr/share/icons/Humanity",
  # FIXME: Remove when apt-ftparchive
  # has better symlink support
  "usr/lib/GNUstep",
  "usr/share/icons",
  "usr/share")

ICON_EXTS = (".svg", ".png", ".xpm", ".tiff", ".gif",
             ".ico", ".jpg", ".jpeg", ".svgz")
_ICON_REGEX = ".*/{0}({exts}|)$".format("{0}", exts="|".join(ICON_EXTS))


class IconFinder:
    """
    Searches for application icons according to a search policy. Queries
    require a ContentsIndex where all paths in 'IconFinder.prefixes' are
    indexed.
    """

    def search(self, icon_name, index):
        """
        Searches the archive for the best icon with a given name.

        @icon_name: A valid Icon string for an XDG Desktop Entry.
        @index: A ContentsIndex with this finder's prefixes indexed.
        @returns ('packagename', 'path/to/icon') or None
        """
        if icon_name.startswith("/"):
            # match an absolute path
            result = index.search_exact(icon_name)
            if result:
                return (result, icon_name.strip("/"))
            # if the path has no extention, search all valid ones.
            # this is actually fairly cheap.
            if os.path.splitext(icon_name)[1] not in ICON_EXTS:
                for ext in ICON_EXTS:
                    returned = self.search(icon_name + ext, index)
                    if returned:
                        return returned
        else:
            # match any path ending with the name and an extension
            icon_name = self._extensionless(icon_name)
            pattern = _ICON_REGEX.format(icon_name)
            for prefix in self.prefixes:
                results = index.search(pattern, prefix)
                if results:
                    return results[0]

    def _extensionless(self, path):
        # utility function to intelligently strip icon extensions
        if any([path.endswith(ext) for ext in ICON_EXTS]):
            return os.path.splitext(path)[0]
        return path

    prefixes = _SEARCH_POLICY
