#!/usr/bin/env python3
import os.path
import subprocess
import sys
import unittest

sys.path.insert(0, "..")
from src.ContentsIndex import ContentsIndex
from src.DesktopFinder import DesktopFinder

CONTENTS_PATH = "archive/dists/test/Contents-foo.gz"
DESKTOP_ENTRIES = (
  # all desktop files of architecture 'foo'
  ("alt-standard-app", "usr/share/applications/a/standard-app.desktop"),
  ("foreign-icon-app", "usr/share/applications/foreign-icon-app.desktop"),
  ("standard-app", "usr/share/applications/standard-app.desktop"))


class DesktopFinderTest(unittest.TestCase):
    """
    Tests the proper operation of DesktopFinder, which searches for XDG
    desktop entries using a ContentsIndex.
    """

    @classmethod
    def setUpClass(self):
        self.index = ContentsIndex(CONTENTS_PATH, DesktopFinder.prefixes)

    def test_desktop_search(self):
        """desktop finder should find applications"""
        finder = DesktopFinder()
        results = finder.search(self.index)
        self.assertCountEqual(results, DESKTOP_ENTRIES)


if __name__ == "__main__":
    if not os.path.exists(CONTENTS_PATH):
        subprocess.call("./build_test_archive")
    unittest.main()
