#!/usr/bin/env python3
import os.path
import subprocess
import sys
import unittest

sys.path.insert(0, "..")
from src.ContentsIndex import ContentsIndex
from src.IconFinder import IconFinder

CONTENTS_PATH = "archive/dists/test/Contents-foo.gz"
ICONS = {
  # failure case
  "this-icon-does-not-exist.png": None,
  # normal search
  "standard-app.png": ("standard-app",
  "usr/share/icons/hicolor/64x64/apps/standard-app.png"),
  # incorrect extension
  "standard-app.gif": ("standard-app",
  "usr/share/icons/hicolor/64x64/apps/standard-app.png"),
  # unthemed absolute search
  "/usr/share/icons/hicolor/64x64/apps/standard-app": ("standard-app",
  "usr/share/icons/hicolor/64x64/apps/standard-app.png"),
  # icons from other packages
  "foreign-icon": ("foreign-icon-pkg",
  "usr/share/icons/hicolor/64x64/apps/foreign-icon.png")}


class IconFinderTest(unittest.TestCase):
    """
    Tests the proper operation of Index, which locates exact and themed
    icons using a ContentsIndex.
    """

    @classmethod
    def setUpClass(self):
        self.index = ContentsIndex(CONTENTS_PATH, IconFinder.prefixes)

    def test_icon_search(self):
        """icon finder should find icons (obviously)"""
        finder = IconFinder()
        for search_name, correct_result in ICONS.items():
            result = finder.search(search_name, self.index)
            self.assertEqual(result, correct_result)


if __name__ == "__main__":
    if not os.path.exists(CONTENTS_PATH):
        subprocess.call("./build_test_archive")
    unittest.main()
